'use strict';

/**
 * Compares two values.
 * @param a a value
 * @param b another value
 * @returns a<b: -1, a=b: 0, a>b: 1
 */
function cmp(a, b) {
    return a < b ? -1 : (a > b ? 1 : 0);
}

/**
 * Gives values present in any array.
 * @param x an array (updated)
 * @param y another array
 * @param fn compare function (a, b)
 * @returns x
 */
function union$(x, y, fn = null) {
    var fn = fn || cmp;
    y: for (var v of y) {
        for (var u of x)
            if (fn(u, v) === 0)
                continue y;
        x.push(v);
    }
    return x;
}

/**
 * Removes duplicate values.
 * @param x an array
 * @param fn compare function (a, b)
 */
function unique(x, fn = null) {
    return union$([], x, fn);
}

module.exports = unique;
